@@ -1,5 +1,5 @@
 from Py_FS.evaluation.evaluate import evaluate
 
 __all__ = [
-    'evaluate'
+    'evaluate',
 ]
\ No newline at end of file
