@@ -8,7 +8,8 @@ Date of Development: 28/10/2020
 from ReliefF import ReliefF
 import numpy as np
 from Py_FS.filter._utilities import normalize, Result
-# from sklearn import datasets
+# _utilities import normalize, Result
+from sklearn import datasets
 
 def Relief(data, target):
     # function that assigns scores to features according to Relief algorithm
